# -*- coding: utf-8 -*-

"""Top-level package for PrettyQt."""

from . import core
from . import widgets
from . import gui
from . import syntaxhighlighters

__author__ = """Philipp Temminghoff"""
__email__ = 'phil65@kodi.tv'
__version__ = '0.13.1'

__all__ = ["core", "widgets", "gui", "syntaxhighlighters"]
